@@ -14,11 +14,11 @@
 static inline bool sb_mkdirat_pre_check(WRAPPER_ARGS_PROTO)
 {
 	char canonic[SB_PATH_MAX];
+
 	save_errno();
 
 	if (-1 == canonicalize(pathname, canonic))
-		/* Path is too long to canonicalize, do not fail, but just let
-		 * the real function handle it (see bug #94630 and #21766). */
+		/* see comments in check_syscall() */
 		if (ENAMETOOLONG != errno)
 			return false;
 
@@ -32,8 +32,9 @@ static inline bool sb_mkdirat_pre_check(WRAPPER_ARGS_PROTO)
 	}
 
 	restore_errno();
+
 	return true;
 }
-#define WRAPPER_PRE_CHECKS() if (!sb_mkdirat_pre_check(WRAPPER_ARGS)) return result;
+#define WRAPPER_PRE_CHECKS() sb_mkdirat_pre_check(WRAPPER_ARGS)
 
 #include "__wrapper_simple.c"
